@@ -43,7 +43,7 @@ __author__    = "Hao Zhu"
 __copyright__ = "Copyright 2019"
 __date__      = '2019/05/28'
 __license__   = "MIT"
-__version__   = "1.1.1"
+__version__   = "1.1.2"
 __email__     = "hz808@nyu.edu"
 
 # Import Needed Modules
@@ -51,6 +51,7 @@ import numpy as np
 from numpy import matlib
 import mne
 import pickle
+import os
 
 #Main function of Reference Electrode Standardization Technique
 def REST_re_reference(eeg_raw_data,montage='standard_1005',mode="average",reference_ch='Cz'):
@@ -63,7 +64,7 @@ def REST_re_reference(eeg_raw_data,montage='standard_1005',mode="average",refere
 	else:
 		pass
 
-	G_dic = pickle.load(open(f'Lead_Field/{montage}_LeadField.p','rb')) #load leadfiled dictionary
+	G_dic = pickle.load(open(f'{os.path.dirname(__file__)}/Lead_Field/{montage}_LeadField.p','rb')) #load leadfiled dictionary
 
 	G = np.array([G_dic[ch] for ch in eeg_raw_data.info['ch_names']]) #get corresponding LeadField Matrix 
 
